@@ -6,12 +6,12 @@ Documentation for transientNamer can be found here: http://transientNamer.readth
 Usage:
     transientNamer [-c] cone <ra> <dec> <arcsecRadius> [<render> | mysql <tableNamePrefix>] [-o directory]
     transientNamer [-c] search <name> [<render> | mysql <tableNamePrefix>] [-o directory]
-    transientNamer [-c] new <discInLastDays> [<render> | mysql <tableNamePrefix>] [-o directory]
+    transientNamer [-c] new <reportedInLastDays> [<render> | mysql <tableNamePrefix>] [-o directory]
 
 Commands:
     cone                  perform a conesearch on the TNS
     search                perform a name search on the TNS
-    new                   list newly discovered TNS objects
+    new                   list newly reported TNS objects
     
 Arguments:
     ra
@@ -21,7 +21,7 @@ Arguments:
     render                output format for results. Options include json, csv, table, markdown, yaml
     tableNamePrefix       the prefix for the tables to write the mysql insert statements for
     directory             path to the directory to save the output to
-    discInLastDays        download and parse only discoveries within the last <n> days
+    reportedInLastDays    download and parse data reported within the last <n> days
     mysql                 generate mysql insert scripts
 
 Options:
@@ -43,9 +43,11 @@ from fundamentals import tools, times
 from subprocess import Popen, PIPE, STDOUT
 import transientNamer
 
+
 def tab_complete(text, state):
     return (glob.glob(text + '*') + [None])[state]
 
+
 def main(arguments=None):
     """
     *The main function used when `cl_utils.py` is run as a single script from the cl, or when installed as a cl command*
@@ -97,7 +99,7 @@ def main(arguments=None):
     tableNamePrefix = a["tableNamePrefix"]
 
     mysql = a["mysql"]
-    discInLastDays = a["discInLastDays"]
+    reportedInLastDays = a["reportedInLastDays"]
     withCommentsFlag = a["withCommentsFlag"]
     outputFlag = a["outputFlag"]
 
@@ -161,10 +163,10 @@ def main(arguments=None):
                 name=name,
                 comments=withCommentsFlag
             )
-        if discInLastDays:
+        if reportedInLastDays:
             tns = transientNamer.search(
                 log=log,
-                discInLastDays=discInLastDays,
+                discInLastDays=reportedInLastDays,
                 comments=withCommentsFlag
             )
 
